@@ -4,7 +4,8 @@ from .models import (
     CreateDataSourceModel,
     CheckAccessModel,
     CheckMultipleAccessModel,
-    FgaObjectModel
+    FgaObjectModel,
+    FgaObjectsModel
 )
 
 __all__ = [
@@ -13,7 +14,8 @@ __all__ = [
     "CreateDataSourceModel",
     "CheckAccessModel",
     "CheckMultipleAccessModel",
-    "FgaObjectModel"
+    "FgaObjectModel",
+    "FgaObjectsModel"
 ]
-__version__ = "0.2.5"
+__version__ = "0.2.6"
 __author__ = "IntelliOps"
